![neomodel](https://raw.githubusercontent.com/neo4j-contrib/neomodel/master/doc/source/_static/neomodel-300.png)

An extension of [neomodel](https://github.com/neo4j-contrib/neomodel) object-graph-mapper (OGM) for the [neo4j](https://neo4j.com/) graph
database, built on the awesome
[neo4j_driver](https://github.com/neo4j/neo4j-python-driver) and [pydantic](https://github.com/pydantic/pydantic).

## Installation

Use pip to install the package:

```bash
pip install neomodantic
```

## Credits

This project is forked from [neomodel](https://github.com/neo4j-contrib/neomodel) and reworked to promote OGM classes to [pydantic](https://github.com/pydantic/pydantic) models. The project is under active development.

## License

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for more details.

